﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 고속 라인
        /// </summary>
        private FastLine fastLine;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "FastLine 클래스 : TreatNulls 속성을 사용해 NULL 값 처리하기";

            this.dontPaintRadioButton.Checked = true;

            this.tChart.Panel.Pen = new ChartPen(Color.Black);

            this.fastLine = new FastLine(this.tChart.Chart);

            this.fastLine.TreatNulls = TreatNullsStyle.DoNotPaint;

            bool done = false;

            for(int x = 0; x <= 100; x++)
            {
                double y = (x % 2 == 0) ? 10 : 20;

                if((x >= 30) && (x <= 70))
                {
                    if(!done)
                    {
                        this.fastLine.Add(x, 0, Color.Transparent);
                    }

                    done = true;
                }
                else
                {
                    this.fastLine.Add(x, y);
                }
            }

            this.fastLine.GetVertAxis.SetMinMax(-10, 30);

            this.dontPaintRadioButton.CheckedChanged += treatNullsRadioButton_CheckedChanged;
            this.skipRadioButton.CheckedChanged      += treatNullsRadioButton_CheckedChanged;
            this.ignoreRadioButton.CheckedChanged    += treatNullsRadioButton_CheckedChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region NULL 처리 라디오 버튼 체크 변경시 처리하기 - treatNullsRadioButton_CheckedChanged(sender, e)

        /// <summary>
        /// NULL 처리 라디오 버튼 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treatNullsRadioButton_CheckedChanged(object sender, EventArgs e)
        {
            if(this.dontPaintRadioButton.Checked)
            {
                this.fastLine.TreatNulls = TreatNullsStyle.DoNotPaint;
            }
            else if(this.skipRadioButton.Checked)
            {
                this.fastLine.TreatNulls = TreatNullsStyle.Skip;
            }
            else
            {
                this.fastLine.TreatNulls = TreatNullsStyle.Ignore;
            }
        }

        #endregion
    }
}